# krezi

Commonly used functions to improve coding experience and avoid repeatability. As I am publishing this package for learning purposes, this library is not written to be foolproof. Use wisely. 

Overall the package provides the following utilities:
1. Logging
2. Subprocessing : to run commands in terminal.
3. Multiprocessing : to work around GIL and utilize multiple cores/threads. Applicable to Dataframes too.
4. Emailing : to send email alerts on demand/error.
5. Stopwatch : to profile scripts. IMO there are better profilers out there. This is just a POC. 
6. Postgresql : Querying from Postgres Databases.
7. MSSQL : Querying from Microsoft SQL Server Databases.
8. Mongo : Querying from Mongo Databases. 
